#! /bin/bash
# Install script for privoxy by Martijn Dekker <martijn@inlv.org>
# Generated by privoxy.SlackBuild for privoxy-3.0.6pl2-i486-1McD.tgz on 18-Jan-2007

function upd_conf {
 	# If there's no config file by that name, mv it over:
 	if ! test -f $1; then
 		mv $1.new $1
 	elif diff --brief $1 $1.new; then	# toss the redundant copy
 		rm $1.new
 	elif ! test -s $1.new; then
 		rm $1.new   # do not keep empty initial files (e.g. log)
 	fi
 	# Otherwise, we leave the .new copy for the admin to consider...
}

function free_user_id {
 	# Find a free user-ID >= 100 (should be < 1000 so it's not a normal user)
 	local FREE_USER_ID=100
 	while grep --quiet "^.*:.*:$FREE_USER_ID:.*:.*:.*:" /etc/passwd; do
 		let FREE_USER_ID++
 	done
 	echo $FREE_USER_ID
}

TMPFILE=$(mktemp /tmp/privoxy.XXXXXX)

# In case we are upgrading to a new version, update path to the manual's
# directory in existing config file. We do this before updating the config
# files; it's not worth leaving a .new file over, and we want the manual to
# always keep working even if the admin never notices the .new file.
if test -f etc/privoxy/config; then
 	sed "s@/usr/doc/privoxy-.*/user-manual@/usr/doc/privoxy-3.0.6/user-manual@"	\
 		etc/privoxy/config > $TMPFILE
 	if ! diff --brief etc/privoxy/config $TMPFILE > /dev/null; then
 		cat $TMPFILE > etc/privoxy/config	# this doesn't alter perms
 	fi
fi

# Edit rc.privoxy script and logrotate file with currently used user/group
# (it's not worth leaving a .new file over)
if test -f etc/rc.d/rc.privoxy; then
 	sed '	/^PRIVOXY_USER=/	s/=.*/="privoxy"/
 		/^PRIVOXY_GROUP=/	s/=.*/="privoxy"/
 		' etc/rc.d/rc.privoxy > $TMPFILE
 	if ! diff etc/rc.d/rc.privoxy $TMPFILE > /dev/null; then
 		echo -n "Changing user/group in /etc/rc.d/rc.privoxy to " 1>&2
 		echo "[1mprivoxy[0m:[1mprivoxy[0m." 1>&2
 		cat $TMPFILE > etc/rc.d/rc.privoxy	# this doesn't alter perms
 	fi
fi
if test -f etc/logrotate.d/privoxy; then
 	sed '/create/	s/\([0-9][0-9][0-9]\)[[:blank:]].*/\1 privoxy privoxy/
 		' etc/logrotate.d/privoxy > $TMPFILE
 	if ! diff etc/logrotate.d/privoxy $TMPFILE > /dev/null; then
 		echo -n "Changing user/group in /etc/logrotate.d/privoxy to " 1>&2
 		echo "[1mprivoxy[0m:[1mprivoxy[0m." 1>&2
 		cat $TMPFILE > etc/logrotate.d/privoxy	# this doesn't alter perms
 	fi
fi

rm $TMPFILE

# Set up group if needed
grep --quiet '^privoxy:' etc/group || groupadd privoxy

# Set up user: add it if it doesn't exist, update it if it already does.
# In any case, make sure it has or gets a user ID between 100 and 999.
# If username changed, determine old username so we can change it (look
# for entry with homedir /var/{log,run}/privoxy).
if OLD_ENTRY=$(grep --max-count=1 '^privoxy:' /etc/passwd) \
 	|| OLD_ENTRY=$(grep --max-count=1 \
 		':/var/[lr][ou][gn]/privoxy:[a-z/]*$' /etc/passwd)
then
 	# Modify existing user
 	OLD_USER=$(echo $OLD_ENTRY | cut --fields=1 --delimiter=':')
 	OLD_USER_ID=$(echo $OLD_ENTRY | cut --fields=3 --delimiter=':')
 	OLD_GROUP_ID=$(echo $OLD_ENTRY | cut --fields=4 --delimiter=':')
 	if test "$OLD_USER" != "privoxy"; then
 		echo -n "[31mChanging[0m unprivileged user [1m$OLD_USER[0m to" 1>&2
 	else
 		echo -n "Updating unprivileged user" 1>&2
 	fi
 	echo " [1mprivoxy[0m with group [1mprivoxy[0m." 1>&2
 	if test $OLD_USER_ID -ge 1000; then
 		USER_ID=$(free_user_id)
 		find etc/privoxy -user $OLD_USER_ID |
 			xargs --no-run-if-empty chown $USER_ID
 	else
 		USER_ID=$OLD_USER_ID
 	fi
 	find etc/privoxy -group $OLD_GROUP_ID |
 		xargs --no-run-if-empty chgrp privoxy
 	usermod -l privoxy -g privoxy -d /var/run/privoxy \
 		-u $USER_ID -s /bin/false -c "Privacy Proxy" $OLD_USER
else
 	# Add new user
 	echo "Adding unprivileged user [1mprivoxy[0m with group [1mprivoxy[0m." 1>&2
 	useradd -g privoxy -d /var/run/privoxy -u $(free_user_id) \
 		-s /bin/false -c "Privacy Proxy" privoxy
fi

# Set up permissions
chown --recursive privoxy:privoxy \
 	var/log/privoxy \
 	var/run/privoxy \
	etc/privoxy/config.new \
	etc/privoxy/trust.new \
	etc/privoxy/global.action.new \
	etc/privoxy/standard.action.new \
	etc/privoxy/user.action.new \
	etc/privoxy/default.filter.new \
	etc/privoxy/user.filter.new 
chgrp privoxy etc/privoxy/default.action.new

# Update configuration files
{
	upd_conf etc/logrotate.d/privoxy
	upd_conf etc/privoxy/config
	upd_conf etc/privoxy/default.action
	upd_conf etc/privoxy/default.filter
	upd_conf etc/privoxy/global.action
	upd_conf etc/privoxy/standard.action
	upd_conf etc/privoxy/templates/blocked
	upd_conf etc/privoxy/templates/cgi-error-404
	upd_conf etc/privoxy/templates/cgi-error-bad-param
	upd_conf etc/privoxy/templates/cgi-error-disabled
	upd_conf etc/privoxy/templates/cgi-error-file
	upd_conf etc/privoxy/templates/cgi-error-file-read-only
	upd_conf etc/privoxy/templates/cgi-error-modified
	upd_conf etc/privoxy/templates/cgi-error-parse
	upd_conf etc/privoxy/templates/cgi-style.css
	upd_conf etc/privoxy/templates/connect-failed
	upd_conf etc/privoxy/templates/default
	upd_conf etc/privoxy/templates/edit-actions-add-url-form
	upd_conf etc/privoxy/templates/edit-actions-for-url
	upd_conf etc/privoxy/templates/edit-actions-for-url-filter
	upd_conf etc/privoxy/templates/edit-actions-list
	upd_conf etc/privoxy/templates/edit-actions-list-button
	upd_conf etc/privoxy/templates/edit-actions-list-section
	upd_conf etc/privoxy/templates/edit-actions-list-url
	upd_conf etc/privoxy/templates/edit-actions-remove-url-form
	upd_conf etc/privoxy/templates/edit-actions-url-form
	upd_conf etc/privoxy/templates/mod-local-help
	upd_conf etc/privoxy/templates/mod-support-and-service
	upd_conf etc/privoxy/templates/mod-title
	upd_conf etc/privoxy/templates/mod-unstable-warning
	upd_conf etc/privoxy/templates/no-such-domain
	upd_conf etc/privoxy/templates/show-request
	upd_conf etc/privoxy/templates/show-status
	upd_conf etc/privoxy/templates/show-status-file
	upd_conf etc/privoxy/templates/show-url-info
	upd_conf etc/privoxy/templates/show-version
	upd_conf etc/privoxy/templates/toggle
	upd_conf etc/privoxy/templates/toggle-mini
	upd_conf etc/privoxy/templates/untrusted
	upd_conf etc/privoxy/trust
	upd_conf etc/privoxy/user.action
	upd_conf etc/privoxy/user.filter
	upd_conf etc/rc.d/rc.privoxy
} | sed 's/^/[1mConfig alert: [0m/'

# Initialize /var files (e.g. logs) if not already present
upd_conf var/log/privoxy/jarfile > /dev/null 2>&1
upd_conf var/log/privoxy/logfile > /dev/null 2>&1

# Make us start on boot
if ! grep --quiet "rc.privoxy start" etc/rc.d/rc.local; then
 	echo "Adding Privoxy to /etc/rc.d/rc.local so it starts at bootup time." 1>&2
 	{	echo ''
 		echo '# Privoxy, the privacy web proxy'
 		echo 'test -x /etc/rc.d/rc.privoxy && /etc/rc.d/rc.privoxy start'
 	} >> etc/rc.d/rc.local
else
 	echo "Privoxy is already in /etc/rc.d/rc.local ."
fi

# Make us stop on shutdown
if ! grep --quiet "rc.privoxy stop" etc/rc.d/rc.local_shutdown 2>/dev/null; then
 	echo "Adding Privoxy to /etc/rc.d/rc.local_shutdown so it stops at shutdown time." 1>&2
 	{	echo ""
 		echo "# Privoxy, the privacy web proxy"
 		echo "test -x /etc/rc.d/rc.privoxy && /etc/rc.d/rc.privoxy stop"
 	} >> etc/rc.d/rc.local_shutdown
else
 	echo "Privoxy is already in /etc/rc.d/rc.local_shutdown ."
fi

